#
# spec file for package python-git-pw
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname git-pw
%define skip_python2 1
Name:           python-git-pw
Version:        2.6.0
Release:        1.2
Summary:        A tool for integrating Git with Patchwork
License:        MIT
URL:            https://github.com/getpatchwork/git-pw
Source:         https://files.pythonhosted.org/packages/source/g/%{modname}/%{modname}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  %{python_module arrow >= 0.10}
BuildRequires:  %{python_module click >= 6.0}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pyaml >= 5.1}
BuildRequires:  %{python_module pytest >= 3.0}
BuildRequires:  %{python_module requests > 2.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tabulate >= 0.8}
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
Requires:       git-core
Requires:       python-arrow >= 0.10
Requires:       python-click >= 6.0
Requires:       python-pyaml >= 5.1
Requires:       python-requests > 2.0
Requires:       python-tabulate >= 0.8
Provides:       %{modname} = %{version}
Obsoletes:      %{modname} < %{version}
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
git-pw is a tool for integrating Git with Patchwork, the web-based patch
tracking system.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/git-pw
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LC_ALL=en_US.UTF-8
%pytest

%post
%python_install_alternative git-pw

%postun
%python_uninstall_alternative git-pw

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/git-pw
%{python_sitelib}/git_pw
%{python_sitelib}/git_pw-%{version}-py%{python_version}.egg-info

%changelog
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.0:
  * Use older Python version for click-man
  * Add support for Python 3.12, drop Python 3.7
  * Replace use of pkg\_resources
  * Revert "docs: Switch to furo theme"
  * Add pyproject.toml file
  * docs: Switch to furo theme
  * readthedocs: Also install git-pw
  * readthedocs: Specify requirements
  * Specify OS, tools
  * Add readthedocs config file
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  * Add release note for --since, --before opts
  * patch, series: Add support for '--since' and '--before'
  * utils: Correct type
  * Fix black issues
  * CI: Switch to pypa/gh-action-pypi-publish@release/v1
* Mon Apr  3 2023 pgajdos@suse.com
- python-six is not required
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.4.0
  * Replace implicit optional typedefs
* Fri May  6 2022 pgajdos@suse.com
- version update to 2.3.0
  2.3.0
  - ----
  * Release 2.3.0
  * Drop Python 3.5, 3.6 support, add 3.10
  * Create git-blame-ignore-revs file
  * Blackify code
  * requirements: Uncap docs requirements
  * CI: Add missing anchors
  2.2.3
  - ----
  * Release 2.2.3
  * CI: Generate release
  * rpm: Add README for RPM specs
  * requirements: Uncap test requirements
  * rpm: Yet more spec file changes
  2.2.2
  - ----
  * Release 2.2.2
  * Add missing runtime dependencies
  * rpm: Modify changelog
  2.2.1
  - ----
  * Release 2.2.1
  * requirements: Remove all upper constraint caps
  * rpm: Add pytest as dependency
  2.2.0
  - ----
  * Release 2.2.0
  * rpm: Spec updates
  * Replace mock with unittest.mock
  * Add missing PyYAML type stubs package
  * utils: Add support for 'yaml' formatter
  * trivial: Style fixes
  * README: Update docs for Patchwork 3.0
  * README: Use python3 variants of packages
  * CI: Stop publishing to test.pypi.org
  2.1.2
  - ----
  * Release 2.1.2
  * requirements: Add support for click 8.x
  * tests: Unset PAGER env when testing fallback
  * docs: Update doc name
  * utils: Convert prints to logging calls
  * utils: Log subprocess calls
  2.1.1
  - ----
  * man: Update man pages
  2.1.0
  - ----
  * Add release note for new 'bundle download' options
  * Fix the setup.py warning
  * Allow downloading of series patches to separate files
  * utils: Remove unnecessary future import
  * README: Re-add build status
  * Remove references to Travis
  * Switch to GitHub Actions
  * tox: Add missing 'typing' stubs
  * tox: Fix default Python versions
  * Convert to Python 3-style type hints
  * Add release note for read-only auth change
  * Do not require authentication for GET requests
- python-mock is not required for build
* Wed Jul 29 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.0:
  * Drop support for Python 2.7
  * trivial: Use names for options with multiple=True
  * Add '--hash' option for 'git-pw patch list'
  * rpm: Address review comments
  * Add spec file
  * Revert "docs: Increase support range for reno"
  * travis: Add support for GitHub releases
  * docs: Increase support range for reno
* Wed Jun 24 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.9.0:
  * Adds support for Patchwork API v1.2 and introduces five new commands:
    + bundle create
    + bundle update
    + bundle delete
    + bundle add
    + bundle remove
* Tue Mar 31 2020 Matej Cepl <mcepl@suse.com>
- Update to 1.8.1: fixing the bug we filed.
* Tue Mar 31 2020 Matej Cepl <mcepl@suse.com>
- Skip over failing UpdateTestCase.test_update_with_invalid_state test
  (gh#getpatchwork/git-pw#53)
- Add Provides/Obsoletes to rename git-pw to python-git-pw package.
- Replace %%python_only construct with proper alternatives.
* Sun Mar 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.0:
  * no changelog
- Set out proper dependencies
- Fix build without python2
* Wed Nov 27 2019 Johannes Thumshirn <jthumshirn@suse.com>
- Update to v1.7.0
* Sun Feb 10 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.5.1
  + Fix help text for --format to refer to pw.format
* Wed Nov 28 2018 jthumshirn@suse.com
- Initial packaging for openSUSE
